
# Import app configuration class
from config.app import AppConfiguration

# Import app.py bootstrap file
from bootstrap.app import AppBootstrap

# Import service provider
from app.Providers.RouteServiceProvider import RouteServiceProvider

# Import Flask
from flask import Flask

# Create a Core class
class Core:

    # Initialize the Core class
    def __init__(self):
        # Create a Flask app
        self.app = Flask(__name__, 
                        template_folder=AppBootstrap().app_templates_path,
                        static_folder=AppBootstrap().app_static_path,
                        root_path=AppBootstrap().app_base_path
                    )

    # Run the Flask app
    def run(self):
        # Register routes
        self.register_routes()

        # Run the Flask app
        return self.app.run(
            host=AppConfiguration().app_host,
            port=AppConfiguration().app_port,
            debug=AppConfiguration().app_debug
        )

    # Register routes
    def register_routes(self):
        return RouteServiceProvider(self.app).boot()
    


# laraflask/setup.py

from setuptools import setup, find_packages

import glob

# Get a list of all files in the current directory
all_files = glob.glob('*')

setup(
    name='laraflask',
    version='0.5',
    packages=find_packages(),
    data_files=[('laraflask', all_files)], 
    include_package_data=True,
    author='Teguh Rijanandi',
    author_email='teguhrijanandi02@gmail.com',
    description='A flask package for Laraflask',
    license='MIT',
    keywords='laraflask flask package',
    url='https://github.com/laraflask/laraflask',
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Operating System :: OS Independent',
    ],
)

# Build the Distribution Package:
# $ python setup.py sdist
# $ python setup.py sdist bdist_wheel
# $ python -m build

# Install the Distribution Package:
# $ pip install dist/laraflask-0.1.tar.gz

# Uninstall the Distribution Package:
# $ pip uninstall laraflask

# Upload the Distribution Package to PyPI:
# $ twine upload dist/*
